@@ -23,14 +23,6 @@ static PyObject *decode_BLE(PyObject *self, PyObject *args)
 
     if (decoder.decodeBLEJson(bleObject) >= 0) {
       std::string buf;
-      bleObject.remove("servicedata");
-      bleObject.remove("manufacturerdata");
-      bleObject.remove("servicedatauuid");
-      bleObject.remove("type");
-      bleObject.remove("cidc");
-      bleObject.remove("acts");
-      bleObject.remove("cont");
-      BLEdata.remove("track");
       serializeJson(bleObject, buf);
       return Py_BuildValue("s", buf.c_str());
     }
