@@ -228,6 +228,8 @@ bool TheengsDecoder::checkDeviceMatch(const JsonArray& condition,
           break;
         }
       }
+    } else if (mfg_data == nullptr && strstr(cond_str, "no-mfgdata") != nullptr) {
+      match = true;
     } else if (dev_name != nullptr && strstr(cond_str, "name") != nullptr) {
       cmp_str = dev_name;
     } else if (svc_uuid != nullptr && strstr(cond_str, "uuid") != nullptr) {
@@ -604,11 +606,20 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
             jsondata["cont"] = doc["cont"];
           }
 
-          if (((data >> 3) & 0x01) == 1) { // Presence tracking conpatible
+          if (((data >> 3) & 0x01) == 1) { // Discoverable as Device Tracker
             doc.add("track");
             doc["track"] = true;
             jsondata["track"] = doc["track"];
           }
+
+          // bits[7-4]
+          data = getBinaryData(tagstring[2]);
+
+          if (((data >> 0) & 0x01) == 1) { // PRMAC - Potential RMAC device - if not defined with Identity MAC and IRK in Theengs Gateway
+            doc.add("prmac");
+            doc["prmac"] = true;
+            jsondata["prmac"] = doc["prmac"];
+          }
         }
 
         // Octet Byte[2] - Encryption Model
@@ -718,6 +729,11 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
                         temp_val = val & post_proc[i + 1].as<unsigned int>();
                         break;
                       }
+                      case '^': {
+                        long long val = (long long)temp_val;
+                        temp_val = val ^ post_proc[i + 1].as<unsigned int>();
+                        break;
+                      }
                     }
                   } else if (strncmp(post_proc[i].as<const char*>(), "max", 3) == 0) {
                     if (temp_val > post_proc[i + 1].as<double>()) {
@@ -805,8 +821,14 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
               JsonArray lookup = prop["lookup"];
               for (unsigned int i = 0; i < lookup.size(); i += 2) {
                 if (lookup[i].as<std::string>() == value) {
-                  value = lookup[i + 1].as<std::string>();
-                  jsondata[sanitizeJsonKey(kv.key().c_str())] = value;
+                  if (lookup[i + 1].as<std::string>() != lookup[i + 1]) {
+                    int valueint = lookup[i + 1].as<int>();
+                    jsondata[sanitizeJsonKey(kv.key().c_str())] = valueint;
+                  } else {
+                    value = lookup[i + 1].as<std::string>();
+                    jsondata[sanitizeJsonKey(kv.key().c_str())] = value;
+                  }
+
                   success = i_main;
                   break;
                 }
