@@ -25,6 +25,7 @@
 #include "devices/CGDN1_json.h"
 #include "devices/CGH1_json.h"
 #include "devices/CGP1W_json.h"
+#include "devices/CGP23W_json.h"
 #include "devices/CGPR1_json.h"
 #include "devices/GAEN_json.h"
 #include "devices/H5055_json.h"
@@ -48,6 +49,7 @@
 #include "devices/MBXPRO_json.h"
 #include "devices/MS_CDP_json.h"
 #include "devices/MUE4094RT_json.h"
+#include "devices/NODONNIU_json.h"
 #include "devices/Miband_json.h"
 #include "devices/XMTZC04HMKG_json.h"
 #include "devices/XMTZC04HMLB_json.h"
@@ -77,12 +79,14 @@
 #include "devices/Amphiro_json.h"
 #include "devices/OralB_json.h"
 #include "devices/PH10_json.h"
+#include "devices/XOSSX2_json.h"
 #include "devices/TPTH_json.h"
 #include "devices/Mopeka_json.h"
 #include "devices/T201_json.h"
 #include "devices/T301_json.h"
 #include "devices/tracker_json.h"
 #include "devices/iNodeEM_json.h"
+#include "devices/ARANET4_json.h"
 #include "devices/BC08_json.h"
 #include "devices/BM1IN1_json.h"
 #include "devices/BM3IN1_json.h"
@@ -91,10 +95,16 @@
 #include "devices/BWBSDOO_json.h"
 #include "devices/BM2_json.h"
 #include "devices/BM6_json.h"
-#include "devices/JHT_F525_json.h"
+#include "devices/JAALEE_json.h"
+#include "devices/APPLEWATCH_json.h"
+#include "devices/APPLEDEVICE_json.h"
 #include "devices/iBeacon_json.h"
 #include "devices/APPLE_json.h"
 #include "devices/ServiceData_json.h"
+#include "devices/SE_RHT_json.h"
+#include "devices/SE_TEMP_json.h"
+#include "devices/SE_TPROBE_json.h"
+#include "devices/SE_MAG_json.h"
 #include "devices/SBBT_002C_json.h"
 #include "devices/SBBT_002C_ENCR_json.h"
 #include "devices/SBDW_002C_json.h"
@@ -108,6 +118,7 @@ const char* _devices[][2] = {
     {_LYWSD02_json, _LYWSD02_json_props},
     {_LYWSDCGQ_json, _LYWSDCGQ_json_props},
     {_CGP1W_json, _CGP1W_json_props},
+    {_CGP23W_json, _CGP23W_json_props},
     {_CGG1_json_STOCK, _CGG1_json_props},
     {_CGG1_json_ATC1441, _CGG1_json_props},
     {_CGG1_json_PVVX, _CGG1_json_props},
@@ -146,6 +157,7 @@ const char* _devices[][2] = {
     {_H5179_json, _H5179_json_props},
     {_HHCCJCY10_json, _HHCCJCY10_json_props},
     {_MUE4094RT_json, _MUE4094RT_json_props},
+    {_NODONNIU_json, _NODONNIU_json_props},
     {_Mokobeacon_json, _Mokobeacon_json_props},
     {_MBXPRO_json, _MBXPRO_json_props},
     {_iNodeEM_json, _iNodeEM_json_props},
@@ -161,6 +173,7 @@ const char* _devices[][2] = {
     {_SCD4X_json, _SCD4X_json_props},
     {_Skale_json, _Skale_json_props},
     {_SmartDry_json, _SmartDry_json_props},
+    {_ARANET4_json, _ARANET4_json_props},
     {_BC08_json, _BC08_json_props},
     {_BM1IN1_json, _BM1IN1_json_props},
     {_BM3IN1_json, _BM3IN1_json_props},
@@ -179,20 +192,31 @@ const char* _devices[][2] = {
     {_AMPHIRO_json, _AMPHIRO_json_props},
     {_OralB_json, _OralB_json_props},
     {_PH10_json, _PH10_json_props},
+    {_XOSSX2_json, _XOSSX2_json_props},
     {_TPTH_json, _TPTH_json_props},
     {_Mopeka_json, _Mopeka_json_props},
     {_T201_json, _T201_json_props},
     {_T301_json, _T301_json_props},
     {_tracker_json_nut, _tracker_json_props},
+    {_tracker_json_nutale, _tracker_json_props},
     {_tracker_json_itag, _tracker_json_props},
     {_tracker_json_tagit, _tracker_json_props},
     {_tracker_json_tile, _tracker_json_props},
     {_tracker_json_tilename, _tracker_json_props},
-    {_JHT_F525_json, _JHT_F525_json_props},
+    {_tracker_json_theengs01, _tracker_json_props},
+    {_tracker_json_theengs02, _tracker_json_props},
+    {_tracker_json_TICWATCHGTH, _tracker_json_props},
+    {_JAALEE_json, _JAALEE_json_props},
+    {_APPLEWATCH_json, _APPLEWATCH_json_props},
+    {_APPLEDEVICE_json, _APPLEDEVICE_json_props},
     {_ibeacon_json, _ibeacon_json_props},
     {_APPLE_json, _APPLE_json_props},
     {_APPLE_json_at, _APPLE_json_props},
     {_ServiceData_json, _ServiceData_json_props},
+    {_SE_RHT_json, _SE_RHT_json_props},
+    {_SE_TEMP_json, _SE_TEMP_json_props},
+    {_SE_TPROBE_json, _SE_TPROBE_json_props},
+    {_SE_MAG_json, _SE_MAG_json_props},
     {_SBBT_002C_json, _SBBT_002C_json_props},
     {_SBBT_002C_ENCR_json, _SBBT_002C_ENCR_json_props},
     {_SBDW_002C_json, _SBDW_002C_json_props},
